@@ -22,13 +22,12 @@
 ## ---------------------------------------------------------------------
 import warnings
 import numpy as np
-import pandas as pd
 
 from adcc import dot
 from scipy import constants
 
 from . import adc_pp
-from .misc import cached_property
+from .misc import cached_property, requires_module
 from .timings import timed_member_call
 from .Excitation import Excitation, mark_excitation_property
 from .FormatIndex import (FormatIndexAdcc, FormatIndexBase,
@@ -38,6 +37,32 @@ from .ElectronicTransition import ElectronicTransition
 from .FormatDominantElements import FormatDominantElements
 
 
+class EnergyCorrection:
+    def __init__(self, name, function):
+        """A helper class to represent excitation energy
+        corrections.
+
+        Parameters
+        ----------
+        name : str
+            descriptive name of the energy correction
+        function : callable
+            function that takes a :py:class:`Excitation`
+            as single argument and returns the energy
+            correction as a float
+        """
+        if not isinstance(name, str):
+            raise TypeError("name needs to be a string.")
+        if not callable(function):
+            raise TypeError("function needs to be callable.")
+        self.name = name
+        self.function = function
+
+    def __call__(self, excitation):
+        assert isinstance(excitation, Excitation)
+        return self.function(excitation)
+
+
 class FormatExcitationVector:
     def __init__(self, matrix, tolerance=0.01, index_format=None):
         """
@@ -127,8 +152,7 @@ class FormatExcitationVector:
 
 
 class ExcitedStates(ElectronicTransition):
-    def __init__(self, data, method=None, property_method=None,
-                 excitation_energy_corrections={}):
+    def __init__(self, data, method=None, property_method=None):
         """Construct an ExcitedStates class from some data obtained
         from an interative solver or another :class:`ExcitedStates`
         object.
@@ -153,33 +177,45 @@ class ExcitedStates(ElectronicTransition):
         property_method : str, optional
             Provide an explicit method for property calculations to
             override the automatic selection.
-        excitation_energy_corrections : dict, optional
-            Provide a dictionary of functions to compute corrections for
-            excitation energies, called for each excitation individually
         """
         super().__init__(data, method, property_method)
+        self._excitation_energy_corrections = []
+        # copy energy corrections if possible
+        # and avoids re-computation of the corrections
+        if hasattr(data, "_excitation_energy_corrections"):
+            for eec in data._excitation_energy_corrections:
+                correction_energy = getattr(data, eec.name)
+                setattr(self, eec.name, correction_energy)
+                self._excitation_energy += correction_energy
+                self._excitation_energy_corrections.append(eec)
 
-        if hasattr(data, "excitation_energy_corrections"):
-            merged = data.excitation_energy_corrections.copy()
-            merged.update(excitation_energy_corrections)
-            excitation_energy_corrections = merged
+    def __add_energy_correction(self, correction):
+        assert isinstance(correction, EnergyCorrection)
+        if hasattr(self, correction.name):
+            raise ValueError("ExcitedStates already has a correction"
+                             f" with the name '{correction.name}'")
+        correction_energy = np.array([correction(exci)
+                                      for exci in self.excitations])
+        setattr(self, correction.name, correction_energy)
+        self._excitation_energy += correction_energy
+        self._excitation_energy_corrections.append(correction)
 
-        if hasattr(self.reference_state, "excitation_energy_corrections"):
-            merged = self.reference_state.excitation_energy_corrections.copy()
-            merged.update(excitation_energy_corrections)
-            excitation_energy_corrections = merged
+    def __iadd__(self, other):
+        if isinstance(other, EnergyCorrection):
+            self.__add_energy_correction(other)
+        elif isinstance(other, list):
+            for k in other:
+                self += k
+        else:
+            return NotImplemented
+        return self
 
-        self.excitation_energy_corrections = excitation_energy_corrections
-        for key in self.excitation_energy_corrections:
-            corr_function = self.excitation_energy_corrections[key]
-            if not callable(corr_function):
-                raise TypeError("Elements in excitation_energy_corrections "
-                                "must be callable.")
-            # call the function for exc. energy correction
-            correction = np.array([corr_function(exci)
-                                   for exci in self.excitations])
-            setattr(self, key, correction)
-            self._excitation_energy += correction
+    def __add__(self, other):
+        if not isinstance(other, (EnergyCorrection, list)):
+            return NotImplemented
+        ret = ExcitedStates(self, self.method, self.property_method)
+        ret += other
+        return ret
 
     @cached_property
     @mark_excitation_property(transform_to_ao=True)
@@ -338,6 +374,16 @@ class ExcitedStates(ElectronicTransition):
             text += body.format(i=i, ene=self.excitation_energy[i],
                                 ev=self.excitation_energy[i] * eV, **fields)
         text += separator + "\n"
+        if len(self._excitation_energy_corrections):
+            head_corr = "|  Excitation energy includes these corrections:"
+            text += head_corr
+            nspace = len(separator) - len(head_corr) - 1
+            text += nspace * " " + "|\n"
+            maxlen = len(separator) - 8
+            for eec in self._excitation_energy_corrections:
+                label = f"|    - {eec.name:{maxlen}.{maxlen}}|\n"
+                text += label
+            text += separator + "\n"
         return text
 
     def _repr_pretty_(self, pp, cycle):
@@ -392,13 +438,15 @@ class ExcitedStates(ElectronicTransition):
                 ret += separator
         return ret[:-1]
 
+    @requires_module("pandas")
     def to_dataframe(self):
         """
         Exports the ExcitedStates object as :class:`pandas.DataFrame`.
         Atomic units are used for all values.
         """
+        import pandas as pd
         propkeys = self.excitation_property_keys
-        propkeys.extend(self.excitation_energy_corrections.keys())
+        propkeys.extend([k.name for k in self._excitation_energy_corrections])
         data = {
             "excitation": np.arange(0, self.size, dtype=int),
             "kind": np.tile(self.kind, self.size)
